ThemeRepositoryImpl class

Implemented types

Constructors

ThemeRepositoryImpl(SharedPreferences _prefs)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCustomTheme() Future<void>
override
getCustomTheme() Future<CustomThemeData?>
override
getThemeMode() Future<ThemeMode>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustomTheme(CustomThemeData theme) Future<void>
override
setThemeMode(ThemeMode mode) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited