CustomThemeData class
A class that represents a custom theme configuration.
Constructors
- CustomThemeData({required Color primaryColor, required Color accentColor, required Color backgroundColor, required Color textColor, required Brightness brightness, Color surfaceColor = Colors.white, Color errorColor = Colors.red, String? fontFamily})
-
const
- CustomThemeData.fromJson(String json)
-
factory
Properties
- accentColor → Color
-
final
- backgroundColor → Color
-
final
- brightness → Brightness
-
final
- errorColor → Color
-
final
- fontFamily → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surfaceColor → Color
-
final
- textColor → Color
-
final
Methods
-
copyWith(
{Color? primaryColor, Color? accentColor, Color? backgroundColor, Color? textColor, Brightness? brightness, Color? surfaceColor, Color? errorColor, String? fontFamily}) → CustomThemeData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toThemeData(
) → ThemeData
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dark(
) → CustomThemeData -
light(
) → CustomThemeData