DynamicThemeManager class
Properties
- bloc → ThemeBloc
-
no setter
- customTheme → CustomThemeData?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkMode → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeMode → ThemeMode
-
no setter
Methods
-
clearCustomTheme(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCustomTheme(
CustomThemeData theme) → Future< void> -
setThemeMode(
ThemeMode mode) → Future< void> -
toggleTheme(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited